Welcome to ClientVPS Mirrors

Help for package coldrift
Title: Lightweight Column Drift Detection for Tabular Data
Version: 0.1.1
Description: Provides simple and efficient methods to detect column-level data drift between reference and target datasets. Designed for monitoring tabular data pipelines and machine learning inputs using statistical distance measures.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
Imports: stats
NeedsCompilation: no
Packaged: 2026-01-25 09:59:35 UTC; yash
Author: Yash Auti [aut, cre]
Maintainer: Yash Auti <autiyash97@gmail.com>
Repository: CRAN
Date/Publication: 2026-01-29 18:50:06 UTC

Detect Column-Level Data Drift

Description

Compares reference and target datasets to identify column-level drift using statistical distance measures.

Usage

detect_column_drift(reference, target, alpha = 0.05)

Arguments

reference

A data.frame representing baseline data

target

A data.frame representing new incoming data

alpha

Significance level for drift detection

Value

A data.frame with drift statistics per column

Examples

ref <- data.frame(
  age = c(25, 30, 35, 40),
  city = c("A", "B", "A", "C")
)

new <- data.frame(
  age = c(26, 31, 36, 41),
  city = c("A", "B", "C", "C")
)

detect_column_drift(ref, new)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.